==> alg-common-1.36.6-20200603.115336-3-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivitySelectorTest.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;



import junit.framework.TestCase;

import java.util.ArrayList;
import java.util.List;

import static cn.com.duiba.nezha.alg.common.model.activityselectconversionforms.ActivitySelector.select;

public class ActivitySelectorTest extends TestCase {
    protected void setUp() throws Exception {
        super.setUp();
        System.out.println();
    }

    protected void tearDown() throws Exception {
        super.tearDown();
        System.out.println();
    }

    public void testBayesianBandit() throws Exception { //几个候选集

        ActivitySelector bandit = new ActivitySelector();
        ActivityInfo a1 = new ActivityInfo();

        //初始化两个素材

        a1.alpha = 1.990099501;
        a1.beta = 6.4108955089999995;
        a1.count = 4.90099501;
        a1.reward = 0;

        ActivityInfoModel am1 = new ActivityInfoModel();
        am1.activityId = 1815;
        am1.changeScore = 0.1;

    //请求
        Val val = new Val();
        val.globalVal = 200;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisRequest = val;

        //点击
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisClick = val;

        //消耗
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisCost = val;

        //发券
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;


        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;



        ActivityInfoModel am2 = new ActivityInfoModel();
        am2.activityId = 1816;
        am2.changeScore = 0.1;

        val = new Val();
        val.globalVal = 200;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisRequest = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisClick = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisCost = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;


        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;



        ActivityInfoData ada1 = new ActivityInfoData();
        //发券  1815 量大 效果差
        Val val2 = new Val();
        ada1.activityId = 1815;
        val2 = new Val();
        val2.globalVal = 5723;
        val2.appVal = 1118;
        val2.slotVal = 800;

        //请求
        val2 = new Val();
        val2.globalVal = 4410;
        val2.appVal = 782;
        val2.slotVal = 600;
        ada1.request = val2;

        //点击
        val2 = new Val();
        val2.globalVal = 1200;
        val2.appVal = 600;
        val2.slotVal = 150;
        ada1.click = val2;

        //消耗
        val2 = new Val();
        val2.globalVal = 1000;
        val2.appVal = 600;
        val2.slotVal = 100;
        ada1.cost = val2;


        List<ActivityInfoAdWithType> adList=new ArrayList<>();
        //指标好 量少
        ActivityInfoData ada2 = new ActivityInfoData();
        ada2.activityId = 1816;
        val2 = new Val();
        val2.globalVal = 400;
        val2.appVal = 300;
        val2.slotVal = 200;

        val2 = new Val();
        val2.globalVal = 500;
        val2.appVal = 350;
        val2.slotVal = 280;
        ada2.request = val2;

        val2 = new Val();
        val2.globalVal = 350;
        val2.appVal = 300;
        val2.slotVal = 200;
        ada2.click = val2;

        val2 = new Val();
        val2.globalVal = 2000;
        val2.appVal = 900;
        val2.slotVal = 300;
        ada2.cost = val2;


        ActivityInfoAdWithType ad1 = new ActivityInfoAdWithType();
        ad1.activityId = 1815;
        List<AdvertWithType> Adverts = new ArrayList<AdvertWithType>();
        AdvertWithType advert1 = new AdvertWithType();
        advert1.advertId = 001;
        advert1.click = 100;
        advert1.effectPV = 3;
        advert1.globalClick = 100L;
        advert1.globalEffectPV = 5L;
        advert1.ifForms=1;
        AdvertWithType advert2 = new AdvertWithType();
        advert2.advertId = 002;
        advert2.click = 100;
        advert2.effectPV = 10;
        advert2.globalClick = 100L;
        advert2.globalEffectPV = 5L;
        advert2.ifForms=0;
        Adverts.add(advert1);
        Adverts.add(advert2);
        ad1.advertsWithType = Adverts;


        ActivityInfoAdWithType ad2 = new ActivityInfoAdWithType();
        ad2.activityId = 1816;

        Adverts= new ArrayList<AdvertWithType>();
        advert1 = new AdvertWithType();
        advert1.advertId = 001;
        advert1.click = 100;
        advert1.effectPV = 3;


        advert1.globalClick = 100L;
        advert1.globalEffectPV = 5L;

        advert1.ifForms=1;

        advert2 = new AdvertWithType();
        advert2.advertId = 002;
        advert2.click = 100;
        advert2.effectPV = 10;
        advert2.globalClick = 100L;
        advert2.globalEffectPV = 5L;
        advert2.ifForms=0;

        Adverts.add(advert1);
        Adverts.add(advert2);
        ad2.advertsWithType = Adverts;

        adList.add(ad1);
        adList.add(ad2);


        ActivityModel aam1 = new ActivityModel();
        aam1.activityId = 1815;
        aam1.activityType = 1; //活动类型 **new**
        aam1.alpha = 1.5; //模型参数
        aam1.beta = 2; // 模型参数
        aam1.reward = 0; //模型参数
        aam1.count = 0; //模型参数x

        ActivityModel aam2 = new ActivityModel();
        aam2.activityId = 1816;
        aam2.activityType = 1; //活动类型 **new**
        aam2.alpha = 1.5; //模型参数
        aam2.beta = 2; // 模型参数
        aam2.reward = 0; //模型参数
        aam2.count = 0; //模型参数-098rt6t-0rty



        ActivityData aad1 = new ActivityData();
        aad1.slotId = 1;
        aad1.appId = 1;
        aad1.activityId = 1815;
        aad1.changeScore = 0.01;


        Val val5 = new Val();
        val5.globalVal = 2000;
        val5.appVal = 100;
        val5.slotVal = 100;
        aad1.hisRequest = val5;

        val5 = new Val();
        val5.globalVal = 500;
        val5.appVal = 30;
        val5.slotVal = 30;
        aad1.hisClick = val5;

        val5 = new Val();
        val5.globalVal = 10000;
        val5.appVal = 1000;
        val5.slotVal = 1000;
        aad1.hisCost = val5;

        val5 = new Val();
        val5.globalVal = 1000;
        val5.appVal = 200;
        val5.slotVal = 100;


        ActivityData aad2 = new ActivityData();
        aad2.slotId = 1;
        aad2.appId = 1;
        aad2.activityId = 1816;
        aad2.changeScore = 0.02;


        Val val6 = new Val();
        val6.globalVal = 1000;
        val6.appVal = 600;
        val6.slotVal = 300;
        aad2.hisRequest = val6;

        val6 = new Val();
        val6.globalVal = 600;
        val6.appVal = 35;
        val6.slotVal = 35;
        aad2.hisClick = val6;

        val6 = new Val();
        val6.globalVal = 20000;
        val6.appVal = 2000;
        val6.slotVal = 2000;
        aad2.hisCost = val6;

        val6 = new Val();
        val6.globalVal = 1000;
        val6.appVal = 200;
        val6.slotVal = 100;


        List<ActivityModel> actModel = new ArrayList<ActivityModel>();
        List<ActivityData> actData = new ArrayList<ActivityData>();
        actData.add(aad2);
        actData.add(aad1);
        actModel.add(aam2);
        actModel.add(aam1);


        //System.out.println("alistModel_0=" + actModel.get(0).activityId + " alistModel_1" + actModel.get(1).activityId);
        double gama = 0.05;
        int cnt1 = 0,cnt2 = 0;



      for (int i=0;i<=1000;i++){

          System.out.println(i);
          System.out.println("match=========================");

          //List<ActivityInfoModel> activityInfoModelList= match(actModel,actData, adList);


          System.out.println("select====================================");

          SelectActivityResult selectActivityResult=
                  ActivitySelector.select(actModel,actData,gama);
          ActivityModel activityModel =selectActivityResult.activityModel;
          List<SameCostActivitiesInfo>  sameCostActivitiesInfoList=selectActivityResult.sameCostActivitiesInfoList;

          System.out.println( i + " result: " + selectActivityResult.activityModel);

          for (SameCostActivitiesInfo infos:sameCostActivitiesInfoList ){
              Long activityId = infos.activityId;
              int sameActivityCnt = infos.sameActivityCnt;
              Long activityType = infos.activityType;
              int ifSelected = infos.ifSelected;
              int index = infos.index;
              double mabReward = infos.mabReward;
              double changeScore = infos.changeScore;
              double diffChangeScore = infos.diffChangeScore;

              System.out.println( infos.toString());
          }

          if (activityModel.activityId==1816){
              cnt1 +=1;
          }
          else {cnt2 +=1;}
      }

        System.out.println("cnt1816= "+cnt1);
        System.out.println("cnt1815= " +cnt2);

        double sumClickForms=99 ;
        int w1 = (int) (sumClickForms / 100 / 0.2);
        System.out.println("w1= "+ w1);

        /*
        Gson gs = new Gson();
        for(int i = 0;i<1000;i++)
        {
            String objectStr1 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            String objectStr2 = gs.toJson(actData.get(1));//把对象转为JSON格式的字符串

            System.out.println("1816"+objectStr2);
            System.out.println("***************");
            List<ActivityInfoModel>  act = bandit.match(actModel, actData, alisAd);

            objectStr1 = gs.toJson(act.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            objectStr2 = gs.toJson(act.get(1));//把对象转为JSON格式的字符串
            System.out.println("1816"+objectStr2);
            break;
            System.out.println(gs.toJson(alisAd.get(0)));
            System.out.println(gs.toJson(alisAd.get(1)));
            for(ActivityInfoModel acm:act){
                System.out.println(acm.activityId);
            }
            System.out.println("--------------------------");
            ActivityModel actm = bandit.select(actModel,actData,0.05);
            String objectStr1 = gs.toJson(actModel.get(0));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr1);
            String objectStr2 = gs.toJson(actModel.get(1));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr2);


            String objectStr3 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr3);
            String objectStr4 = gs.toJson(actm);//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr4);
            System.out.println((i+1)+"th act = "+actm.activityId+" alpha="+act.alpha+" beta="+act.beta+" count="+act.count+" reward="+act.reward);
            System.out.println((i+1)+"th act = "+actm.activityId);

            if (actm.activityId == 1815) {
                actModel.set(1, actm);//update
                cnt2++;
            } else if (actm.activityId == 1816) {
                actModel.set(0, actm);
                cnt1++;
            }
            System.out.println("***********************");
            System.out.println("alpha="+m.alpha+"\t"+"beta="+m.beta+"\t"+"reward="+m.reward+" count="+"\t"+m.count+"\t");
            break;
        }
        System.out.println("1816 cnt1 = "+cnt1+"|| 1815 cnt2="+cnt2);
    }

    public Comparator<Integer> iComparator = new Comparator<Integer>() {

        @Override
        public int compare(Integer c1, Integer c2) {
            return (int) (c2 - c1);
        }
    };


*/
    }
}

==> alg-common-2.5.3-20190825.085630-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivitySelectorTest.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;



import junit.framework.TestCase;

import java.util.ArrayList;
import java.util.List;

import static cn.com.duiba.nezha.alg.common.model.activityselectconversionforms.ActivitySelector.select;

public class ActivitySelectorTest extends TestCase {
    protected void setUp() throws Exception {
        super.setUp();
        System.out.println();
    }

    protected void tearDown() throws Exception {
        super.tearDown();
        System.out.println();
    }

    public void testBayesianBandit() throws Exception { //几个候选集

        ActivitySelector bandit = new ActivitySelector();
        ActivityInfo a1 = new ActivityInfo();

        //初始化两个素材

        a1.alpha = 1.990099501;
        a1.beta = 6.4108955089999995;
        a1.count = 4.90099501;
        a1.reward = 0;

        ActivityInfoModel am1 = new ActivityInfoModel();
        am1.activityId = 1815;
        am1.changeScore = 0.1;

    //请求
        Val val = new Val();
        val.globalVal = 200;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisRequest = val;

        //点击
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisClick = val;

        //消耗
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisCost = val;

        //发券
        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.hisSend = val;


        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.lastSend = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.lastRequest = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.lastClick = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am1.lastCost = val;



        ActivityInfoModel am2 = new ActivityInfoModel();
        am2.activityId = 1816;
        am2.changeScore = 0.1;

        val = new Val();
        val.globalVal = 200;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisRequest = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisClick = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisCost = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.hisSend = val;


        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.lastSend = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.lastRequest = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.lastClick = val;

        val = new Val();
        val.globalVal = 0;
        val.appVal = 0;
        val.slotVal = 0;
        am2.lastCost = val;



        ActivityInfoData ada1 = new ActivityInfoData();
        //发券  1815 量大 效果差
        Val val2 = new Val();
        ada1.activityId = 1815;
        val2 = new Val();
        val2.globalVal = 5723;
        val2.appVal = 1118;
        val2.slotVal = 800;
        ada1.send = val2;  //发券

        //请求
        val2 = new Val();
        val2.globalVal = 4410;
        val2.appVal = 782;
        val2.slotVal = 600;
        ada1.request = val2;

        //点击
        val2 = new Val();
        val2.globalVal = 1200;
        val2.appVal = 600;
        val2.slotVal = 150;
        ada1.click = val2;

        //消耗
        val2 = new Val();
        val2.globalVal = 1000;
        val2.appVal = 600;
        val2.slotVal = 100;
        ada1.cost = val2;


        List<ActivityInfoAdWithType> adList=new ArrayList<>();
        //指标好 量少
        ActivityInfoData ada2 = new ActivityInfoData();
        ada2.activityId = 1816;
        val2 = new Val();
        val2.globalVal = 400;
        val2.appVal = 300;
        val2.slotVal = 200;
        ada2.send = val2;

        val2 = new Val();
        val2.globalVal = 500;
        val2.appVal = 350;
        val2.slotVal = 280;
        ada2.request = val2;

        val2 = new Val();
        val2.globalVal = 350;
        val2.appVal = 300;
        val2.slotVal = 200;
        ada2.click = val2;

        val2 = new Val();
        val2.globalVal = 2000;
        val2.appVal = 900;
        val2.slotVal = 300;
        ada2.cost = val2;


        ActivityInfoAdWithType ad1 = new ActivityInfoAdWithType();
        ad1.activityId = 1815;
        List<AdvertWithType> Adverts = new ArrayList<AdvertWithType>();
        AdvertWithType advert1 = new AdvertWithType();
        advert1.advertId = 001;
        advert1.click = 100;
        advert1.effectPV = 3;
        advert1.globalClick = 100L;
        advert1.globalEffectPV = 5L;
        advert1.ifForms=1;
        AdvertWithType advert2 = new AdvertWithType();
        advert2.advertId = 002;
        advert2.click = 100;
        advert2.effectPV = 10;
        advert2.globalClick = 100L;
        advert2.globalEffectPV = 5L;
        advert2.ifForms=0;
        Adverts.add(advert1);
        Adverts.add(advert2);
        ad1.AdvertsWithType = Adverts;


        ActivityInfoAdWithType ad2 = new ActivityInfoAdWithType();
        ad2.activityId = 1816;

        Adverts= new ArrayList<AdvertWithType>();
        advert1 = new AdvertWithType();
        advert1.advertId = 001;
        advert1.click = 100;
        advert1.effectPV = 3;


        advert1.globalClick = 100L;
        advert1.globalEffectPV = 5L;

        advert1.ifForms=1;

        advert2 = new AdvertWithType();
        advert2.advertId = 002;
        advert2.click = 100;
        advert2.effectPV = 10;
        advert2.globalClick = 100L;
        advert2.globalEffectPV = 5L;
        advert2.ifForms=0;

        Adverts.add(advert1);
        Adverts.add(advert2);
        ad2.AdvertsWithType = Adverts;

        adList.add(ad1);
        adList.add(ad2);


        ActivityModel aam1 = new ActivityModel();
        aam1.activityId = 1815;
        aam1.activityType = 1; //活动类型 **new**
        aam1.alpha = 1.5; //模型参数
        aam1.beta = 2; // 模型参数
        aam1.reward = 0; //模型参数
        aam1.count = 0; //模型参数x

        ActivityModel aam2 = new ActivityModel();
        aam2.activityId = 1816;
        aam2.activityType = 1; //活动类型 **new**
        aam2.alpha = 1.5; //模型参数
        aam2.beta = 2; // 模型参数
        aam2.reward = 0; //模型参数
        aam2.count = 0; //模型参数-098rt6t-0rty



        ActivityData aad1 = new ActivityData();
        aad1.slotId = 1;
        aad1.appId = 1;
        aad1.activityId = 1815;
        aad1.changeScore = 0.01;


        Val val5 = new Val();
        val5.globalVal = 2000;
        val5.appVal = 100;
        val5.slotVal = 100;
        aad1.hisRequest = val5;

        val5 = new Val();
        val5.globalVal = 500;
        val5.appVal = 30;
        val5.slotVal = 30;
        aad1.hisClick = val5;

        val5 = new Val();
        val5.globalVal = 10000;
        val5.appVal = 1000;
        val5.slotVal = 1000;
        aad1.hisCost = val5;

        val5 = new Val();
        val5.globalVal = 1000;
        val5.appVal = 200;
        val5.slotVal = 100;
        aad1.hisSend = val5;


        ActivityData aad2 = new ActivityData();
        aad2.slotId = 1;
        aad2.appId = 1;
        aad2.activityId = 1816;
        aad2.changeScore = 0.02;


        Val val6 = new Val();
        val6.globalVal = 1000;
        val6.appVal = 600;
        val6.slotVal = 300;
        aad2.hisRequest = val6;

        val6 = new Val();
        val6.globalVal = 600;
        val6.appVal = 35;
        val6.slotVal = 35;
        aad2.hisClick = val6;

        val6 = new Val();
        val6.globalVal = 20000;
        val6.appVal = 2000;
        val6.slotVal = 2000;
        aad2.hisCost = val6;

        val6 = new Val();
        val6.globalVal = 1000;
        val6.appVal = 200;
        val6.slotVal = 100;
        aad2.hisSend = val6;


        List<ActivityModel> actModel = new ArrayList<ActivityModel>();
        List<ActivityData> actData = new ArrayList<ActivityData>();
        actData.add(aad2);
        actData.add(aad1);
        actModel.add(aam2);
        actModel.add(aam1);


        //System.out.println("alistModel_0=" + actModel.get(0).activityId + " alistModel_1" + actModel.get(1).activityId);
        double gama = 0.05;
        int cnt1 = 0,cnt2 = 0;



      for (int i=0;i<=1000;i++){

          System.out.println(i);
          System.out.println("match=========================");

          //List<ActivityInfoModel> activityInfoModelList= match(actModel,actData, adList);


          System.out.println("select====================================");

          SelectActivityResult selectActivityResult= ActivitySelector.select(actModel,actData, gama);
          ActivityModel activityModel =selectActivityResult.activityModel;
          List<SameCostActivitiesInfo>  sameCostActivitiesInfoList=selectActivityResult.sameCostActivitiesInfoList;

          System.out.println( i + " sameCostActivitiesInfoList: " + sameCostActivitiesInfoList);

          for (SameCostActivitiesInfo infos:sameCostActivitiesInfoList ){
              Long activityId = infos.activityId;
              int sameActivityCnt = infos.sameActivityCnt;
              Long activityType = infos.activityType;
              int ifSelected = infos.ifSelected;
              int index = infos.index;
              double mabReward = infos.mabReward;
              double changeScore = infos.changeScore;
              double diffChangeScore = infos.diffChangeScore;

              System.out.println( "activityId: "+ activityId + " sameActivityCnt: "+ sameActivityCnt + " activityType: "+ activityType
                      + " ifSelected: "+ ifSelected+ " index: "+ index+ " mabReward: "+ mabReward+ " changeScore: "+ changeScore
                      + " diffChangeScore: "+ diffChangeScore);}

          if (activityModel.activityId==1816){
              cnt1 +=1;
          }
          else {cnt2 +=1;}
      }

        System.out.println("cnt1816= "+cnt1);
        System.out.println("cnt1815= " +cnt2);

        double sumClickForms=99 ;
        int w1 = (int) (sumClickForms / 100 / 0.2);
        System.out.println("w1= "+ w1);

        /*
        Gson gs = new Gson();
        for(int i = 0;i<1000;i++)
        {
            String objectStr1 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            String objectStr2 = gs.toJson(actData.get(1));//把对象转为JSON格式的字符串

            System.out.println("1816"+objectStr2);
            System.out.println("***************");
            List<ActivityInfoModel>  act = bandit.match(actModel, actData, alisAd);

            objectStr1 = gs.toJson(act.get(0));//把对象转为JSON格式的字符串
            System.out.println("1815"+objectStr1);
            objectStr2 = gs.toJson(act.get(1));//把对象转为JSON格式的字符串
            System.out.println("1816"+objectStr2);
            break;
            System.out.println(gs.toJson(alisAd.get(0)));
            System.out.println(gs.toJson(alisAd.get(1)));
            for(ActivityInfoModel acm:act){
                System.out.println(acm.activityId);
            }
            System.out.println("--------------------------");
            ActivityModel actm = bandit.select(actModel,actData,0.05);
            String objectStr1 = gs.toJson(actModel.get(0));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr1);
            String objectStr2 = gs.toJson(actModel.get(1));//把对象转为JSON格式的字符串
            System.out.println("actModel"+objectStr2);


            String objectStr3 = gs.toJson(actData.get(0));//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr3);
            String objectStr4 = gs.toJson(actm);//把对象转为JSON格式的字符串
            System.out.println("actData"+objectStr4);
            System.out.println((i+1)+"th act = "+actm.activityId+" alpha="+act.alpha+" beta="+act.beta+" count="+act.count+" reward="+act.reward);
            System.out.println((i+1)+"th act = "+actm.activityId);

            if (actm.activityId == 1815) {
                actModel.set(1, actm);//update
                cnt2++;
            } else if (actm.activityId == 1816) {
                actModel.set(0, actm);
                cnt1++;
            }
            System.out.println("***********************");
            System.out.println("alpha="+m.alpha+"\t"+"beta="+m.beta+"\t"+"reward="+m.reward+" count="+"\t"+m.count+"\t");
            break;
        }
        System.out.println("1816 cnt1 = "+cnt1+"|| 1815 cnt2="+cnt2);
    }

    public Comparator<Integer> iComparator = new Comparator<Integer>() {

        @Override
        public int compare(Integer c1, Integer c2) {
            return (int) (c2 - c1);
        }
    };


*/
    }
}
